
/**
 * Representation of a single sample of sensor values from the Finch.  In particular,
 * a sample contains:
 * <UL>
 * <LI>  The light levels (left and right channels)
 * <LI>  The acceleration levels (X, Y, and Z) in units of 'g'
 * <LI>  The obstacle values (boolean representing whether an obstacle is there or not)
 *     		for the left and right sensors
 * <LI>  The temperature level (in Celsius)
 * <LI>  The time (in milliseconds) that the sample was taken.
 * </UL>
 * <P>
 * 
 * @author Andrew H. Fagg and Steven Ness
 *
 */ 

public class FinchSensor 
{
	/**
	 * Holds the array of light values
	 */
	private int light[];
	
	/**
	 * Holds the array of acceleration values
	 */
	private double acceleration[];
	
	/**
	 * Holds the array of obstacle values
	 */
	private boolean obstacle[];
	
	/**
	 * Holds the temperature value
	 */
	private double temperature;
	
	/**
	 * The time (in milliseconds) that the sample was taken. 
	 */
	private long sample_time;
	
	/**
	 * Primary constructor
	 * 
	 * @param light			2-element array of light levels
	 * @param acceleration	3-element array of acceleration values
	 * @param obstacle		2-element array of obstacle values
	 * @param temperature	Temperature
	 * @param sample_time	Time in ms that the sample was taken
	 */
	public FinchSensor(int light[], double acceleration[], 
			boolean obstacle[], double temperature, Long sample_time)
	{
		this.light = light;
		this.acceleration = acceleration;
		this.obstacle = obstacle;
		this.temperature = temperature;
		this.sample_time = sample_time;
	}
	
	/**
	 * Accessor to acceleration
	 * 
	 * @return	Array of acceleration values
	 */
	public double[] getAcceleration()
	{
		return(acceleration);
	}
	
	/**
	 * Accessor to temperature.
	 * 
	 * @return The temperature
	 */
	
	public double getTemperature()
	{
		return(temperature);
	}
	
	/**
	 * Light level accessor
	 * 
	 * @return The array of light levels
	 */
	
	public int[] getLight()
	{
		return(light);
	}
	
	/**
	 * Accessor to obstacle sensor 
	 * 
	 * @return The obstacle sensor array
	 */
	
	public boolean[] getObstacle()
	{
		return(obstacle);
	}
	
	/**
	 * Accessor for the sensor sample time.
	 * 
	 * @return time that this sample was collected
	 */
	public long getSampleTime() {
		return(sample_time);
	}
	
	/**
	 * Overriding the Object toString method
	 * 
	 * @return	A representation of this object as a String
	 */
	public String toString()
	{
		return(this.sample_time + " " +
				this.light[0] + " " +
				this.light[1] + " " +
				this.acceleration[0] + " " +
				this.acceleration[1] + " " +
				this.acceleration[2] + " " +
				this.obstacle[0] + " " +
				this.obstacle[1] + " " +
				this.temperature);
	}

}